export default class CollapsibleMenu {

	constructor (menuElements) {

		this.menuElements = menuElements;
		this.windowWidth = '60em';
		this.matchMedia = window.matchMedia(`(min-width: ${this.windowWidth})`);
		this.toggleElementClassName = 'js-collapsible-menu__toggle';
		this.classToggle = 'g-menu--collapsed';

		this.init();

	}

	init () {

		this.mediaChanged(this.matchMedia);

		this.matchMedia.addEventListener('change', (event) => this.mediaChanged(event));

		for (const menuElement of this.menuElements) {
			const labelElements = menuElement.getElementsByClassName(this.toggleElementClassName);

			for (const label of labelElements) {
				label.addEventListener('click', () => this.labelClicked(menuElement, labelElements));
			}
		}

	}

	mediaChanged (event) {

		return this.updateElements(event.matches);

	}

	updateElements (isVisible) {

		for (const menuElement of this.menuElements) {
			const labelElements = menuElement.getElementsByClassName(this.toggleElementClassName);

			if (isVisible) {
				menuElement.classList.remove(this.classToggle);
			} else {
				menuElement.classList.add(this.classToggle);
			}

			for (const label of labelElements) {
				this.updateElement(label, isVisible);
			}
		}

	}

	updateElement (label, isVisible) {
		label.setAttribute('aria-expanded', isVisible ? 'true' : 'false');

	}

	labelClicked (menuElement, labels) {
		menuElement.classList.toggle(this.classToggle);
		const isVisible = !menuElement.classList.contains(this.classToggle);

		for (const label of labels) {
			this.updateElement(label, isVisible);
		}

	}

}
