import ParameterValidator from '@mvps-genesis/parameter-validator';
import HTMLFormValidator from './HTMLFormValidator';

/*
 *--------------------------------------------------------------------------
 * HTML Forms Validator
 *--------------------------------------------------------------------------
 *
 * Class to add inline validation to multiple HTML forms.
 *
 */

export default class HTMLFormsValidator {

	/**
	 * Parameter Validator object
	 *
	 * @var	@mvps-genesis/parameter-validator
	 */
	#validator;

	/**
	 * Selector to indicate which forms should have the HTMLFormValidator applied to them. Default is '.js-form-validator'
	 *
	 * @var String
	 */
	formSelector;

	/**
	 * Otions object that will be passed on to the HTMLFormValidator. See class constructor() for option definitions.
	 *
	 * @var Object
	 * @property	String		formsSelector
	 */
	options;

	/**
	 * NodeList of forms being validated
	 *
	 * @var NodeList
	 */
	forms;

	/**
	 * Array of the results initializing the HTMLFormValidator class
	 *
	 * @var Array
	 */
	formValidators;

	/**
	 * Create a new HTMLFormValidator object
	 *
	 * @property	Object	options	See options variable definition above for properties documentation.
	 */
	constructor (formsSelector, options) {
		this.#validator = new ParameterValidator(this);

		this.formsSelector = this.#validator.isString('formsSelector', formsSelector || '.js-form-validator');
		this.options = this.#validator.isObject('options', options);
		this.formValidators = [];

		this.init();
	}

	init () {
		this.forms = document.querySelectorAll(this.formsSelector);

		if (this.forms.length) {
			for (const formElement of this.forms) {
				formElement.HTMLFormValidator = new HTMLFormValidator({
					...{formElement},
					...this.options
				});
				this.formValidators.push(formElement.HTMLFormValidator);
			}
		}
	};

}
