/* eslint-disable array-element-newline */
/* eslint-disable max-lines-per-function */
/* eslint-disable no-sync */
/* eslint-disable global-require */
const {Compilation} = require('webpack');

module.exports = class JuiceWebpackPlugin {
	constructor (options) {
		this.options = options;

		this.juiceRules = {
			juice: {
				codeBlocks: {
					mvt: {
						end: '/>',
						start: '<mvt:'
					}
				}
			},
			preserveImportant: true,
			xmlMode: true
		};

		this.mivaTemplatesFilePath = this.options.mivaTemplatesFilePath;
		this.juiceTemplatesFilePath = this.options.juiceTemplatesFilePath;
	}

	/**
	 * @param {import('webpack').Compiler} compiler
	 */
	apply (compiler) {
		const regex = /^juice\..*$/;
		compiler.hooks.compilation.tap('JuiceWebpackPlugin', (compilation) => {
			compilation.hooks.processAssets.tap(
				{
					additionalAssets: true,
					name: 'JuiceWebpackPlugin',
					stage: Compilation.PROCESS_ASSETS_STAGE_OPTIMIZE
				},
				(assets) => {
					for (let assetName in assets) {
						if (regex.test(assetName)) {
							if (assetName === 'juice.css') {
								this.processJuice(assets[assetName]);
							}
							delete assets[assetName];
						}
					}
				}
			);
		});
	}

	async processJuice (asset) {
		const cssnano = require('cssnano');
		const juice = require('juice');
		const fs = require('fs');

		// Minify the output from webpack
		const {css} = await cssnano({
			discardComments: {
				removeAll: true
			}
		}).process(asset.source());

		let juicedEmail = '';
		this.juiceRules.extraCss = css;

		const templates = {
			contentsections: [],
			pages: []
		};

		fs.readdirSync(`${this.juiceTemplatesFilePath}templates`).forEach((file) => {
			const readData = fs.readFileSync(`${this.juiceTemplatesFilePath}templates/${file}`);
			juicedEmail = this.mvtSanitize(juice(readData.toString(), this.juiceRules));
			fs.writeFileSync(`${this.mivaTemplatesFilePath}templates/${file}`, juicedEmail);
			templates.pages.push({
				code: file.replace('.mvt', ''),
				contents: juicedEmail
			});
		});

		fs.readdirSync(`${this.juiceTemplatesFilePath}readytheme_contentsection`).forEach((file) => {
			const readData = fs.readFileSync(`${this.juiceTemplatesFilePath}readytheme_contentsection/${file}`);
			juicedEmail = this.mvtSanitize(juice(readData.toString(), this.juiceRules));
			fs.writeFileSync(`${this.mivaTemplatesFilePath}properties/readytheme_contentsection/${file}`, juicedEmail);
			templates.contentsections.push({
				code: file.replace('.mvt', ''),
				contents: juicedEmail
			});
		});

		fs.writeFileSync('./src/juice-emails/imports/_emails.xml', this.generateXML(templates));
	}

	mvtSanitize (fileContent) {
		return fileContent
			.replace(/<\/mvt:elseif>|<\/mvt:else>/g, '')
			.replace(/align="-webkit-center"/g, 'align="center"');
	}

	generateXML (templates) {
		let xml = '';

		for (const page of templates.pages) {
			// Check if a page's code with - is in it, to determine if it's an item
			let isPage = 1;
			for (const parentPage of templates.pages) {
				if (page.code.includes(`${parentPage.code}-`)) {
					isPage = 0;

					xml += `
						<Page_Update code="${parentPage.code.toUpperCase()}">
							<Item code="${page.code.replace(`${parentPage.code}-`, '')}">
								<Template>${this.cdataEncode(page.contents)}</Template>
							</Item>
						</Page_Update>
					`;

					break;
				}
			}

			if (isPage) {
				xml += `
					<Page_Update code="${page.code.toUpperCase()}">
						<Template>${this.cdataEncode(page.contents)}</Template>
					</Page_Update>
				`;
			}
		}

		xml += `<Module code="readytheme" feature="component">`;
		for (const page of templates.contentsections) {
			xml += `
				<ContentSection_Update code="${page.code}">
					<Template>${this.cdataEncode(page.contents)}</Template>
				</ContentSection_Update>
			`;
		}
		xml += `</Module>`;

		return xml;
	}

	cdataEncode (string) {
		return ('<![CDATA[' + string).replace(/\]\]>/g, ']]]]><![CDATA[>') + ']]>';
	}
};
