/* eslint-disable no-process-env */

// Core
const {merge} = require('webpack-merge');
const path = require('path');
const commonConfig = require('./webpack.common.js');
const themeSettings = require('./theme-settings.json');

// Plugins
const BrowserSyncPlugin = require('browser-sync-webpack-plugin');

// Define `environment`
const environment = themeSettings.environments[process.env.THEME_ENV];

// Merge common and local configurations
module.exports = merge(commonConfig, {
	devtool: 'cheap-source-map',
	mode: 'development',
	output: {
		chunkFilename: '[contenthash].chunk.js',
		filename: '[name].js',
		path: path.resolve(__dirname, 'public/dist'),
		publicPath: `/${environment.moduleRoot}/_local/dist/`
	},
	performance: {
		hints: false
	},
	plugins: [
		new BrowserSyncPlugin(
			{
				cors: true,
				files: ['src/**'],
				https: true,
				open: false,
				proxy: {
					target: environment.proxyUrl
				},
				rewriteRules: [
					{
						match: new RegExp(`(b[0-9]+/)?${environment.themePath}(public/)?`, 'g'),
						replace: '_local/'
					}
				],
				serveStatic: [
					{
						dir: 'public',
						route: `/${environment.moduleRoot}/_local`
					}
				]
			},
			{
				injectCss: true,
				reload: false,
				stream: true
			}
		)
	],
	watch: true
});
